QAlgebra
========

[![Source code on Github](https://img.shields.io/badge/qalgebra-qalgebra-blue.svg?logo=github)](https://github.com/qalgebra/qalgebra)
[![QAlgebra on the Python Package Index](https://img.shields.io/pypi/v/qalgebra.svg)](https://pypi.python.org/pypi/qalgebra)
[![Documentation](https://img.shields.io/badge/Docs-gh--pages-blue.svg)](https://qalgebra.github.io/qalgebra/)
[![Docs](https://github.com/QAlgebra/qalgebra/workflows/Docs/badge.svg?branch=master)](https://github.com/QAlgebra/qalgebra/actions?query=workflow%3ADocs)
[![Tests](https://github.com/QAlgebra/qalgebra/workflows/Tests/badge.svg?branch=master)](https://github.com/QAlgebra/qalgebra/actions?query=workflow%3ATests)
[![Coveralls](https://img.shields.io/coveralls/github/QAlgebra/qalgebra/master.svg)](https://coveralls.io/github/QAlgebra/qalgebra)
[![MIT License](https://img.shields.io/badge/License-MIT-green.svg)](https://opensource.org/licenses/MIT)


Python package for symbolic quantum algebra.

Development of QAlgebra happens on [Github](https://github.com/qalgebra/qalgebra). You can read the full documentation [online](https://qalgebra.github.io/qalgebra/).


Installation
------------

To install the latest released version of QAlgebra, run this command in your terminal:

~~~
pip install qalgebra
~~~

This is the preferred method to install QAlgebra, as it will always install the most recent stable release.

If you don't have [pip](https://pip.pypa.io) installed, the [Python installation guide](http://docs.python-guide.org/en/latest/starting/installation/), respectively the [Python Packaging User Guide](https://packaging.python.org/tutorials/installing-packages/) can guide you through the process.

To install the latest development version of QAlgebra from [Github](https://github.com/qalgebra/qalgebra).

~~~
pip install git+https://github.com/qalgebra/qalgebra.git@master#egg=qalgebra
~~~


Usage
-----

To use QAlgebra in a project:

~~~
import qalgebra
~~~
